@@ -1,30 +1,28 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
-    # Voodoo
+# Voodoo
 
-    Reanimates an application skeleton, just for you.
-    
-    ------------
-    Copyright © 2011 by [Lúcuma labs] (http://lucumalabs.com).
-    See `AUTHORS.md` for more details.
-    License: [MIT License] (http://www.opensource.org/licenses/mit-license.php).
+Reanimates an application skeleton, just for you.
+
+------------
+Copyright © 2011 by [Lúcuma labs] (http://lucumalabs.com).  
+See `AUTHORS.md` for more details.  
+License: [MIT License] (http://www.opensource.org/licenses/mit-license.php).
 
 """
 import datetime
 import errno
+import io
 import os
 import re
 
 import jinja2
 
 
-__version__ = '0.5'
+__version__ = '0.6'
 
 
-COLOR_OKGREEN = '\033[92m'
-COLOR_END = '\033[0m'
-
 DEFAULT_DATA = {
     'PS': os.path.sep,
     'NOW': datetime.datetime.utcnow(),
@@ -40,6 +38,20 @@ DEFAULT_ENV_OPTIONS = {
     'variable_end_string': ']]',
 }
 
+COLORS = {
+    'OKGREEN': '\033[92m',
+    'INFO': '\033[93m',
+    'FAIL': '\033[91m',
+    'BOLD': '\033[1m',
+    'ENDC': '\033[0m',
+}
+
+
+def formatm(action, msg='', color='OKGREEN'):
+    color = COLORS.get(color, '')
+    lparts = [color, action, COLORS['ENDC'], msg]
+    return ''.join(lparts)
+
 
 def make_dirs(*lpath):
     path = os.path.join(*lpath)
@@ -51,6 +63,19 @@ def make_dirs(*lpath):
     return path
 
 
+def read_from(filepath, mode='rb'):
+    with io.open(filepath, mode) as f:
+        source = f.read()
+    return source
+
+
+def make_file(filepath, content, mode='wb'):
+    if not isinstance(content, unicode):
+        content = unicode(content, 'utf-8')
+    with io.open(filepath, mode) as f:
+        f.write(content)
+
+
 def reanimate_skeleton(skeleton_path, new_app_path, data=None, filter_ext=None,
         env_options=None):
     
@@ -71,9 +96,6 @@ def reanimate_skeleton(skeleton_path, new_app_path, data=None, filter_ext=None,
     _env_options.setdefault('loader', jinja_loader)
     env_options = _env_options
     
-    print 'Using skeleton:', skeleton_path
-    print '\n  %s/' % new_app_path
-    
     jinja_env = jinja2.Environment(**env_options)
 
     for folder, subs, files in os.walk(skeleton_path):
@@ -83,11 +105,7 @@ def reanimate_skeleton(skeleton_path, new_app_path, data=None, filter_ext=None,
             if filename.endswith(filter_ext):
                 continue
             src_path = os.path.join(folder, filename)
-            f = open(src_path, 'rb')
-            try:
-                content = f.read()
-            finally:
-                f.close()
+            content = read_from(src_path)
             
             if filename.endswith('.tmpl'):
                 if not isinstance(content, unicode):
@@ -97,16 +115,10 @@ def reanimate_skeleton(skeleton_path, new_app_path, data=None, filter_ext=None,
                 content = tmpl.render(data).encode('utf-8')
             filename = re.sub(r'%PNAME%', pname, filename)
             
-            msg = ''.join([
-                COLOR_OKGREEN, '    create', COLOR_END, '  ',
-                os.path.join(ffolder, filename).lstrip('.').lstrip('/'),
-                ])
-            print msg
+            created_path = os.path.join(ffolder, filename) \
+                .lstrip('.').lstrip('/')
+            print formatm('    create', created_path)
             
             final_path = make_dirs(new_app_path, ffolder, filename)
-            f = open(final_path, 'wb')
-            try:
-                f.write(content)
-            finally:
-                f.close()
+            make_file(final_path, content)
 
